Learn R Programming

fundManageR (version 0.5.0113)

get_data_finra_people: FINRA registered people

Description

This function returns information for any Financial Industry Regulatory Authority [FINRA] registered entity.

Usage

get_data_finra_people(search_name = NULL, ocr_pdf = TRUE, return_message = TRUE)

Arguments

search_name
vector of names to search
ocr_pdf
if TRUE returns OCR'd broker report PDF
return_message
return a message upon parsing TRUE, FALS
score_threshold
matching score threshold for the search name if NULL there is no threshold

Value

a data frame

References

FINRA

See Also

Other FINRA: get_data_adv_managers_metadata, get_data_finra_entities

Other IAPD: get_data_adv_managers_current_period_summary, get_data_adv_managers_filings, get_data_adv_managers_metadata, get_data_adv_managers_periods_summaries, get_data_finra_entities

Examples

Run this code
get_data_finra_people(search_name = 'Llyod Blankfein', ocr_pdf = TRUE)

Run the code above in your browser using DataLab